pub struct Router { /* private fields */ }Expand description
Router is a service that nests other services on chosen routes
For example:
let mut router = Router::new();
router.add("/hello", DefaultService);This will show the hello message on this route, and fire a 404 on others.
Routes can be of two types:
- exact (does not end with
/) - nested (ends with
/)
Exact route is a hashmap match, nested route matches anything under chosen route.
Nested route example:
router.add("/files/", FilesService::new("files"));This code will host all files in the “files” dir, under route /files/.
Note that it also matches just /files, and that nested routes strip their prefix -
so /files/something becomes /something in the route argument. Original route is still
accessible via req.route
Nested routes are implemented with a linear search, consider something more optimized if you have thousands of them
Errors
When a route cannot be matched, Router fires a StatusCode(404)
Implementations